@@ -4,15 +4,21 @@
 # This source code is licensed under the BSD-style license found in the
 # LICENSE file in the root directory of this source tree.
 
+# pyre-strict
+
 from torcheval.metrics.ranking.click_through_rate import ClickThroughRate
 from torcheval.metrics.ranking.hit_rate import HitRate
 from torcheval.metrics.ranking.reciprocal_rank import ReciprocalRank
+from torcheval.metrics.ranking.retrieval_precision import RetrievalPrecision
+from torcheval.metrics.ranking.retrieval_recall import RetrievalRecall
 from torcheval.metrics.ranking.weighted_calibration import WeightedCalibration
 
 __all__ = [
     "ClickThroughRate",
     "HitRate",
     "ReciprocalRank",
+    "RetrievalPrecision",
+    "RetrievalRecall",
     "WeightedCalibration",
 ]
 __doc_name__ = "Ranking Metrics"
